bayespy.inference.vmp.nodes.gaussian.GaussianGammaToGaussianWishart.lower_bound_contribution
============================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianGammaToGaussianWishart.lower_bound_contribution